@@ -3,9 +3,9 @@ import json
 import requests
 import math
 
-from openweatherclass.openweatherclass.geodataclass import GeoDataClass
-from openweatherclass.openweatherclass.historydataclass import HistoricDataClass
-from openweatherclass.openweatherclass.weatherdataclass import WeatherDataClass
+from openweatherclass.geodataclass import GeoDataClass
+from openweatherclass.historydataclass import HistoricDataClass
+from openweatherclass.weatherdataclass import WeatherDataClass
 
 with open("WeatherClass/condition_codes.json", mode='r') as file:
     CONDITIONS_JSON = json.load(file)
